# -*- coding: utf-8 -*-

from django import forms
from django.conf import settings
from django.core.mail import send_mail
from django.template.loader import render_to_string
from django.template import Context
from django.utils.translation import ugettext_lazy as _
from isolmant.organisation.models import Contact, ContactSource, ContactCategory, PurchaseCategory


class ContactForm(forms.Form):
    SET_ACTIVITY = (
        ("", "---"),
        ("progettista", _("Designer")),
        ("produzione", _("Production Manager")),
        ("commerciale", _("Commercial/Sales")),
        ("tecnico", _("Technical")),
        ("acquisti", _("Purchasing Manager")),
        ("altro", _("Other")),
    )

    contact_category = forms.ModelChoiceField(
        label=_("Category"),
        queryset=ContactCategory.objects.filter(status=1)
    )
    role = forms.ChoiceField(
        label=_("Activity"),
        choices=settings.ISOLMANT_ORGANISATION_CONTACT_ROLE_CHOICES
    )
    purchase_category = forms.ModelChoiceField(
        label=_("Area of interest"),
        queryset=PurchaseCategory.objects.filter(status=1)
    )

    first_name = forms.CharField(label=_("First Name"))
    last_name = forms.CharField(label=_("Last Name"))
    organisation_name = forms.CharField(label=_("Company"), required=False)
    address = forms.CharField(label=_("Complete Address"), required=False)
    zip_code = forms.CharField(label=_("Zip Code"), required=False, max_length=6)
    city = forms.CharField(label=_("City"), required=False)
    province = forms.CharField(label=_("Province"), required=False)
    country = forms.CharField(label=_("Country"), required=False)
    email = forms.EmailField()
    phone = forms.CharField(label=_("Phone"), required=False)
    fax = forms.CharField(label=_("Fax"), required=False)
    message = forms.CharField(
        label=_("Message"),
        required=True,
        widget=forms.Textarea(attrs={'placeholder': _("Type your message here"), 'cols': '80'})
    )
    privacy = forms.BooleanField(label=_("Privacy"))

    def save(self):
        contact = Contact()
        for field in self.cleaned_data.keys():
            if hasattr(contact, field):
                setattr(contact, field, self.cleaned_data[field])
        try:
            contact.source = ContactSource.objects.get(name__icontains='sito web')
        except:
            pass
        contact.save()
        return self.send_email()

    def send_email(self):
        data = self.cleaned_data
        recipient_list = [settings.ISOLMANT_CONTACT_MAIL]
        context = Context({'site': settings.BASE_URL})
        for field in data.keys():
            context[field] = data[field]

        # messaggio testuale
        text_message = render_to_string(
            'organisation/email/contact_email.txt',
            context
        )

        # messaggio html
        html_message = render_to_string(
            'organisation/email/contact_email.html',
            context
        )

        try:
            msg = send_mail(
                subject=u"Nuovo contatto: {0} {1}".format(context['first_name'], context['last_name']),
                message=text_message,
                html_message=html_message,
                recipient_list=recipient_list,
                from_email=data['email'],
            )
            return True, msg
        except Exception, e:
            return False, e


class NewsletterForm(forms.Form):
    first_name = forms.CharField(label=_("First Name"))
    last_name = forms.CharField(label=_("Last Name"))
    email = forms.EmailField()
    privacy = forms.BooleanField(label=_("Privacy"))

    def save(self):
        contact = Contact()
        for field in self.cleaned_data.keys():
            if hasattr(contact, field):
                setattr(contact, field, self.cleaned_data[field])
        try:
            contact.source = ContactSource.objects.get(name__icontains='sito web')
        except:
            pass
        contact.save()
        return self.send_email()

    def send_email(self):
        data = self.cleaned_data
        recipient_list = [settings.ISOLMANT_CONTACT_MAIL]
        context = Context({'site': settings.BASE_URL})
        for field in data.keys():
            context[field] = data[field]

        # messaggio testuale
        text_message = render_to_string(
            'organisation/email/newsletter_request_email.txt',
            context
        )

        # messaggio html
        html_message = render_to_string(
            'organisation/email/newsletter_request_email.html',
            context
        )
        try:
            msg = send_mail(
                subject=u"Nuovo richiesta iscrizione alla newsletter: {0} {1}".format(context['first_name'], context['last_name']),
                message=text_message,
                html_message=html_message,
                recipient_list=recipient_list,
                from_email=data['email'],
            )
            return True, msg
        except Exception, e:
            return False, e
