# -*- coding: utf-8 -*-

from django.utils.translation import ugettext_lazy as _
import admin_tools
from admin_tools.dashboard import modules, AppIndexDashboard

from jmb.core.admin import dashboard as jmb_dashboard


class DefaultDashboard(modules.Group):
    def __init__(self):

        kwargs = {
            'title': "Organisation",
            'display': "tabs",
            'children': [
                ContactTab(),
                AgentsTab(),
            ]
        }
        super(DefaultDashboard, self).__init__(**kwargs)


class OrganisationDashboard(modules.Group):
    def __init__(self):

        kwargs = {
            'title': "Organisation",
            'display': "tabs",
            'children': [
                ContactTab(),
                AgentsTab(),
            ]
        }
        super(OrganisationDashboard, self).__init__(**kwargs)


class AgentsTab(modules.ModelList):
    def __init__(self):
        kwargs = {
            'title': _("Agents"),
            'models': (
                'isolmant.organisation.models.Agent',
                'isolmant.organisation.models.Province',
                'isolmant.organisation.models.Region',
            ),
        }
        super(AgentsTab, self).__init__(**kwargs)


class ContactTab(modules.ModelList):
    def __init__(self):
        kwargs = {
            'title': _("Contacts"),
            'models': (
                'isolmant.organisation.models.Contact',
                'isolmant.organisation.models.ContactSource',
                'isolmant.organisation.models.ContactCategory',
                'isolmant.organisation.models.PurchaseCategory',
                'isolmant.organisation.models.MailUpMessage',
            ),
        }
        super(ContactTab, self).__init__(**kwargs)


class DefaultAppDashboard(AppIndexDashboard):
    def __init__(self, app_title, models, **kwargs):
        AppIndexDashboard.__init__(self, app_title, models, **kwargs)
        self.columns = 3

    def init_with_context(self, context):
        request = context['request']

        # Registered dashboards
        self.children.append(
            DefaultDashboard(),
        )

# Used in /admin 
jmb_dashboard.register_group(OrganisationDashboard, 'isolmant.organisation')
# Used in /admin/Organisation
admin_tools.dashboard.register(DefaultAppDashboard, 'isolmant.organisation')
