# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Contact',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('first_name', models.CharField(max_length=30, verbose_name='first name')),
                ('last_name', models.CharField(max_length=30, verbose_name='last name')),
                ('email', models.EmailField(max_length=254, verbose_name='email address', blank=True)),
                ('phone', models.CharField(max_length=30, verbose_name='phone number', blank=True)),
                ('mobile', models.CharField(max_length=30, verbose_name='mobile number', blank=True)),
                ('creator', models.ForeignKey(related_name='organisation_contact_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='organisation_contact_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ContactSource',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('name', models.CharField(max_length=30, verbose_name='name')),
                ('description', models.TextField(verbose_name='description', blank=True)),
                ('creator', models.ForeignKey(related_name='organisation_contactsource_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='organisation_contactsource_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='JoinContactOrganisation',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('role', models.CharField(max_length=255, verbose_name='role')),
                ('contact', models.ForeignKey(related_name='organisation_joins', verbose_name='contact', to='organisation.Contact')),
                ('creator', models.ForeignKey(related_name='organisation_joincontactorganisation_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='organisation_joincontactorganisation_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ('organisation__name', 'contact__last_name', 'contact__first_name'),
                'verbose_name': 'join organisation contact',
                'verbose_name_plural': 'joins organisation contact',
            },
        ),
        migrations.CreateModel(
            name='Organisation',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('name', models.CharField(max_length=255, verbose_name='name')),
                ('slug', models.SlugField(max_length=255, verbose_name='slug')),
                ('brand', models.CharField(max_length=255, verbose_name='brand', blank=True)),
                ('ssn', models.CharField(max_length=16, verbose_name='social security number', blank=True)),
                ('vat', models.CharField(max_length=24, verbose_name='vat number', blank=True)),
                ('url', models.URLField(max_length=100, verbose_name='url', blank=True)),
                ('email', models.EmailField(max_length=100, verbose_name='email', blank=True)),
                ('phone', models.CharField(max_length=20, verbose_name='phone', blank=True)),
                ('fax', models.CharField(max_length=20, verbose_name='fax', blank=True)),
                ('creator', models.ForeignKey(related_name='organisation_organisation_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='organisation_organisation_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('members', models.ManyToManyField(related_name='contacts', verbose_name='members', through='organisation.JoinContactOrganisation', to='organisation.Contact')),
            ],
            options={
                'ordering': ('name',),
                'verbose_name': 'organisation',
                'verbose_name_plural': 'organisations',
            },
        ),
        migrations.CreateModel(
            name='OrganisationCategory',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('name', models.CharField(max_length=30, verbose_name='name')),
                ('description', models.TextField(verbose_name='description', blank=True)),
                ('creator', models.ForeignKey(related_name='organisation_organisationcategory_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='organisation_organisationcategory_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='PurchaseCategory',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('name', models.CharField(max_length=30, verbose_name='name')),
                ('description', models.TextField(verbose_name='description', blank=True)),
                ('creator', models.ForeignKey(related_name='organisation_purchasecategory_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='organisation_purchasecategory_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='organisation',
            name='organisation_category',
            field=models.ForeignKey(related_name='organisations', verbose_name='organisation category', blank=True, to='organisation.OrganisationCategory', null=True),
        ),
        migrations.AddField(
            model_name='organisation',
            name='purchase_category',
            field=models.ForeignKey(related_name='organisations', verbose_name='purchase category', blank=True, to='organisation.PurchaseCategory', null=True),
        ),
        migrations.AddField(
            model_name='organisation',
            name='source',
            field=models.ForeignKey(related_name='organisations', verbose_name='contact source', blank=True, to='organisation.ContactSource', null=True),
        ),
        migrations.AddField(
            model_name='joincontactorganisation',
            name='organisation',
            field=models.ForeignKey(related_name='contact_joins', verbose_name='organisation', to='organisation.Organisation'),
        ),
        migrations.AddField(
            model_name='contact',
            name='source',
            field=models.ForeignKey(related_name='contacts', verbose_name='contact source', blank=True, to='organisation.ContactSource', null=True),
        ),
    ]
