# coding: utf-8

import time
import datetime
import logging

from jmb.async.tasks import JmbJobtasticTask

from isolmant.organisation import utils

from mailup.components import Recipient


class NewsLetterSendTask(JmbJobtasticTask):
    task_name = 'Newsletter Send'
    significant_kwargs = []
    herd_avoidance_timeout = 0
    cache_duration = -1

    def calculate_result(self, *args, **kwargs):

        from mailup.logger import LoggerSingleton
        ls = LoggerSingleton()
        ls.setLevel(logging.DEBUG)

        logger = logging.getLogger('celery.task')
        logger.info('TASK START: NewsLetterTask')

        message_id = kwargs['message_id']
        contacts = kwargs['contacts']

        mailup_provider = utils.get_default_mailup_provider()
        mailup_list = utils.get_default_mailup_list()
        message_to_send = mailup_provider.get_message(
            list_id=mailup_list.id,
            message_id=message_id,
        )

        # RECIPIENTS LIST
        recipients = []
        for contact in contacts:
            email = contact.email
            name = '{first} {last}'.format(first=contact.first_name, last=contact.last_name)
            recipient = Recipient(
                data_dict={
                    'Name': name,
                    'Email': email,
                    'idList': mailup_list.id,
                },
                mailup_client=mailup_provider.client,
            )
            recipients.append(recipient)

        # TEMPORARY GROUP
        group_name = 'tmp-{str_date}-{message_subject}'.format(
            str_date=str(datetime.date.today()),
            message_subject=message_to_send.subject,
        )
        temporary_group = mailup_provider.create_group({
            'Name': group_name,
            'Notes': 'Temporary group created with admin action',
            'idList': mailup_list.id
        })
        temporary_group.subscribe_recipients_list_forced(
            recipients=recipients,
        )

        # WAIT NECESSARY FOR MAILUP
        time.sleep(30)

        # MESSAGE SEND
        send_statistic = message_to_send.send_to_group(temporary_group.id)
        # temporary_group.delete()

        logger.info('TASK END: NewsLetterTask')

        return send_statistic
